api.reputation.v1.test_helpers.observation package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.test_helpers.observation package

## Submodules

## api.reputation.v1.test_helpers.observation.add_observations module

`api.reputation.v1.test_helpers.observation.add_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.add_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.add_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.add_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.delete_observations module

`api.reputation.v1.test_helpers.observation.delete_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.delete_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.delete_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.delete_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.fetch_observations_for_domain module

`api.reputation.v1.test_helpers.observation.fetch_observations_for_domain.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.fetch_observations_for_domain.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.fetch_observations_for_domain.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.fetch_observations_for_domain.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.fetch_observations_for_i_p module

`api.reputation.v1.test_helpers.observation.fetch_observations_for_i_p.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.fetch_observations_for_i_p.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.fetch_observations_for_i_p.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.fetch_observations_for_i_p.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.find_address_observations module

`api.reputation.v1.test_helpers.observation.find_address_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/search, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.find_address_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/search, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.find_address_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/search, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.find_address_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip/search, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.find_domain_observations module

`api.reputation.v1.test_helpers.observation.find_domain_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/search, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.find_domain_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/search, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.find_domain_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/search, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.find_domain_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain/search, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.list_address_observations module

`api.reputation.v1.test_helpers.observation.list_address_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.list_address_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.list_address_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.list_address_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/ip, respond with HTTP 401

## api.reputation.v1.test_helpers.observation.list_domain_observations module

`api.reputation.v1.test_helpers.observation.list_domain_observations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain, respond with HTTP 403

`api.reputation.v1.test_helpers.observation.list_domain_observations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain, respond with HTTP 404

`api.reputation.v1.test_helpers.observation.list_domain_observations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain, respond with HTTP 200

`api.reputation.v1.test_helpers.observation.list_domain_observations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/observation/domain, respond with HTTP 401

## Module contents